Description Usage Arguments Details Value Functions Note import_datavyu import_datavyu_to_list Examples
The function will find data exported from .opf to .csv using the built-in Ruby
script.
1 2 3 4 5 6 7 8 9 |
... |
Additional arguments passed to |
as_list |
A logical value indicating to return a list or data frame (default). |
append_colnames |
If |
folder |
Either a scalar character pointing to a directory where contents are to
be scanned, or a vector of |
columns |
Similar to the |
files |
The short name of the Datavyu "file" to import, as used for the original
datavyu |
class_overwrite |
A |
traverse |
Search subfolders of |
Most functions in this package only work if you had previously used the
datavyu2csv.rb script to export a Datavyu file to .csv. This script can be
obtained from ruby_script_folder(). Exported data is in the form of several
"/column__file.csv" files. Files will be searched based on the directory supplied
to the folder argument. Valid files will have the following columns: file,
column, onset, offset, ordinal, along with custom user codes as columns.
See sections import_datavyu and import_datavyu_to_list below.
import_datavyu: Import content as a data.frame or list of
data.frame objects.
import_datavyu_to_list: Imports Datavyu content as a nested list.
If the same column name was used across separate .opf files but has
a different set of datavyu codes then you will get an error unless as_list=TRUE.
import_datavyuReturns one of the objects below.
a single data.frame if a single column or file was found.
a list of data sets if returned if different Datavyu columns are found, where each list entry is the Datavyu column.
import_datavyu_to_listReturns a list with the names:
data: a nested list with files at the top layer and column data within files.
contents: a data.table with the same contents from datavyu_search().
order: The order of files and columns nested within $data.
1 2 3 4 5 6 7 8 9 | import_datavyu(columns="childhands")
import_datavyu(columns="childhands", append_colnames=TRUE)
import_datavyu(columns=c("childhands", "parenthands"), as_list=TRUE)
example_data_info <- datavyu_search(folder=datavyur_internal_data())
import_datavyu(files=example_data_info$file[1])
data_list <- import_datavyu_to_list()
str(data_list)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.